import os
from ..common import prettyllog
from .awx_common import awx_get_id
from .awx_common import getawxdata
import json
import requests


VERIFY_SSL = os.getenv("VERIFY_SSL", "false")
if VERIFY_SSL.lower() == "false" or VERIFY_SSL == "no":
    VERIFY_SSL = False
else:
    VERIFY_SSL = True

############################################################################################################################
# Create organization
############################################################################################################################



def awx_create_organization(name, description, max_hosts, DEE, realm, mytoken, r):
  prettyllog("manage", "organization", name, "update", "000", "Start")
  try:  
    orgid = (awx_get_id("organizations", name,r ))
  except:
    print("Unexcpetede error")

  if (orgid == ""):
    headers = {"User-agent": "python-awx-client", "Content-Type": "application/json","Authorization": "Bearer {}".format(mytoken)}
    data = {
          "name": name,
          "description": description,
          "max_hosts": max_hosts
         }
    url = os.getenv("TOWER_HOST") + "/api/v2/organizations/"
    resp = requests.post(url,headers=headers, json=data, verify=VERIFY_SSL)
    response = json.loads(resp.content)
    try:
      orgid=response['id']
      prettyllog("manage", "organization", name, "exist", resp.status_code, "organization %s created with id %s" % (orgid))
    except:
      prettyllog("manage", "organization", name, "new", resp.status_code, "organization not created")
      print(response)
  else:    
    prettyllog("manage", "organization", name, "exist", "000", "organization already exist")
    headers = {"User-agent": "python-awx-client", "Content-Type": "application/json","Authorization": "Bearer {}".format(mytoken)}
    data = {
          "name": name,
          "description": description,
          "max_hosts": max_hosts
         }
    url = os.getenv("TOWER_HOST") + "/api/v2/organizations/%s" % orgid
    resp = requests.put(url,headers=headers, json=data, verify=VERIFY_SSL)
    response = json.loads(resp.content)
    prettyllog("manage", "organization", name, "update", resp.status_code, response)
  getawxdata("organizations", mytoken, r)
  prettyllog("manage", "organization", name, "end of organization", "000", "End")



from . import dns
from . import cloudflare

import argparse
import os

def check_env():
    if os.environ.get("KALM_DNS_TYPE") == None:
        print("KALM_DNS_TYPE not set")
        exit(1)
    if os.environ.get("KALM_DNS_URL") == None:
        print("KALM_DNS_URL not set")
        exit(1)
    if os.environ.get("KALM_DNS_TOKEN") == None:
        print("KALM_DNS_TOKEN not set")
        exit(1)
    if os.environ.get("KALM_DNS_DOMAIN") == None:
        print("KALM_DNS_DOMAIN not set")
        exit(1)
    if os.environ.get("KALM_DNS_PROVIDER") == None:
        print("KALM_DNS_PROVIDER not set")
        exit(1)
    if os.environ.get("KALM_DNS_ZONEID") == None:
        print("KALM_DNS_ZONEID not set")
        exit(1)
    if os.environ.get("KALM_DNS_RECORD_NAME") == None:
        print("KALM_DNS_RECORD_NAME not set")
        exit(1)
    if os.environ.get("KALM_DNS_RECORD_CONTENT") == None:
        print("KALM_DNS_RECORD_CONTENT not set")
        exit(1)
    if os.environ.get("KALM_DNS_RECORD_TTL") == None:
        os.environ.setdefault("KALM_DNS_RECORD_TTL", "300")
    if os.environ.get("KALM_DNS_RECORD_TYPE") == None:
        os.environ.setdefault("KALM_DNS_RECORD_TYPE", "A")
    if os.environ.get("KALM_DNS_RECORD_PROXIED") == None:
        os.environ.setdefault("KALM_DNS_RECORD_PROXIED", False )
    return True



def main():
    parser = argparse.ArgumentParser(description="Keep kalm and automate", usage="kalm_dns <action> \n\n\
\
               version : 0.9.15 \n\
               actions:\n\
               envcheck    check if env is set \n\
               setenv      set env \n\
               list        list dns records \n\
               sync        sync dns record\n\
               libvirt     create dns records for virtlib\n\
\n\
               2023 Knowit Miracle\n\
               ")
    
    parser.add_argument('action', metavar='<action>', type=str, nargs='+', help='setup netbox')
    args = parser.parse_args()
    ready = False
    if args.action[0] == "sync":
        print("sync dns")
        dns.sync_dns(args)
        
    if args.action[0] == "envcheck":
        print("env check")
        dns.env_check()

    if args.action[0] == "setenv":
        print("set env")
        dns.set_env()
    
    if args.action[0] == "libvirt":
        print("set env")
        dns.libvirt(args)

    if args.action[0] == "default":
        print("set env")
        dns.default(args)

    if args.action[0] == "clean":
        dns.clean(args)

    if args.action[0] == "cloudflare":
        cloudflare.check_access()
        
    if args.action[0] == "list":
        if(cloudflare.check_access()):
            print(cloudflare.list_dns())
            return True
        
    if args.action[0] == "add_record":
        if check_env():
          if(cloudflare.check_access()):
            cloudflare.add_record()   
            return True


    





